@@ -1,7 +1,7 @@
 # Colored terminal output for Python's logging module.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: April 26, 2018
+# Last Change: April 27, 2018
 # URL: https://coloredlogs.readthedocs.io
 
 """
@@ -213,7 +213,7 @@ WINDOWS = sys.platform.startswith('win')
 NEED_COLORAMA = WINDOWS
 
 # Semi-standard module versioning.
-__version__ = '9.1'
+__version__ = '9.2'
 
 DEFAULT_LOG_LEVEL = logging.INFO
 """The default log level for :mod:`coloredlogs` (:data:`logging.INFO`)."""
@@ -858,6 +858,10 @@ class ColoredFormatter(logging.Formatter):
         initializer of the base class.
         """
         self.nn = NameNormalizer()
+        # The use of the logging.getLogRecordFactory() is preferable over
+        # logging.LogRecord in Python 3, but this function isn't available in
+        # Python 2. We'll check the existence of the function just once now.
+        self.log_record_factory = getattr(logging, 'getLogRecordFactory', None)
         # The default values of the following arguments are defined here so
         # that Sphinx doesn't embed the default values in the generated
         # documentation (because the result is awkward to read).
@@ -893,20 +897,28 @@ class ColoredFormatter(logging.Formatter):
         are part of the same whitespace separated token they'll be highlighted
         together in the style defined for the `name` field.
         """
-        result = []
-        for token in fmt.split():
-            # Look for field names in the token.
-            for match in re.finditer(r'%\((\w+)\)', token):
-                # Check if a style is defined for the matched field name.
-                style = self.nn.get(self.field_styles, match.group(1))
-                if style:
-                    # If a style is defined we apply it.
-                    token = ansi_wrap(token, **style)
-                    # The style of the first field name that has a style defined
-                    # `wins' (within each whitespace separated token).
-                    break
-            result.append(token)
-        return ' '.join(result)
+        return re.sub(r'\S+', self.colorize_callback, fmt)
+
+    def colorize_callback(self, match):
+        """
+        Wrap field names in ANSI escape sequences.
+
+        :param match: A regular expression match object.
+        :returns: The matched text, possibly wrapped in ANSI escape sequences.
+
+        This is a callback for :func:`re.sub()` used by :func:`colorize_format()`.
+        """
+        token = match.group(0)
+        # Look for field names in the token.
+        for match in re.finditer(r'%\((\w+)\)', token):
+            # Check if a style is defined for the matched field name.
+            style = self.nn.get(self.field_styles, match.group(1))
+            if style:
+                # If a style is defined we apply it. The style of the first
+                # field name that has a style defined `wins' (within each
+                # whitespace separated token).
+                return ansi_wrap(token, **style)
+        return token
 
     def format(self, record):
         """
@@ -948,7 +960,11 @@ class ColoredFormatter(logging.Formatter):
             # For more details refer to issue 29 on GitHub:
             # https://github.com/xolox/python-coloredlogs/issues/29
             copy = Empty()
-            copy.__class__ = logging.LogRecord
+            copy.__class__ = (
+                self.log_record_factory()
+                if self.log_record_factory is not None
+                else logging.LogRecord
+            )
             copy.__dict__.update(record.__dict__)
             copy.msg = ansi_wrap(coerce_string(record.msg), **style)
             record = copy
